﻿using System;

namespace YTxCommon {
    /// <summary>
    ///     Страны
    /// </summary>
    public enum Countries {
        /// <summary>
        ///     UKR, Украина
        /// </summary>
        UA = 0,

        /// <summary>
        ///     KAZ, Казахстан
        /// </summary>
        KZ = 1,

        /// <summary>
        ///     UZB, Узбекистан
        /// </summary>
        UZ = 2,

        /// <summary>
        ///     AZE, Азербайджан
        /// </summary>
        AZ = 3,

        /// <summary>
        ///     LTU, Литва
        /// </summary>
        LT = 4,

        /// <summary>
        ///     Мальта
        /// </summary>
        MT = 5
    }

    /// <summary>
    ///     Языки системы
    /// </summary>
    public enum SysLangs {
        /// <summary>
        ///     Русский
        /// </summary>
        RU = 0,

        /// <summary>
        ///     Украинский
        /// </summary>
        UK = 1,

        /// <summary>
        ///     Английский
        /// </summary>
        EN = 2,

        /// <summary>
        ///     Литовский
        /// </summary>
        LT = 3,

        /// <summary>
        ///     Азербайджанский
        /// </summary>
        AZ = 4
    }

    /// <summary>
    ///     Режим выборки данных
    /// </summary>
    public enum DataSelectionMode {
        /// <summary>
        ///     Все записи
        /// </summary>
        All,

        /// <summary>
        ///     Активные записи
        /// </summary>
        Active,

        /// <summary>
        ///     Неактивные записи
        /// </summary>
        Inactive,

        /// <summary>
        ///     Для выборки значений
        /// </summary>
        ForSelection
    }

    /// <summary>
    ///     Типы данных полей для валидации
    /// </summary>
    public enum FieldDataTypes {
        Undefined,
        Numeric,
        Decimal
    }

    /// <summary>
    ///     Тип скрипта
    /// </summary>
    public enum ProgrammingLanguage {
        /// <summary>
        ///     VB.Net
        /// </summary>
        VBNet = 0,

        /// <summary>
        ///     C#
        /// </summary>
        CSharp = 1
    }

    #region Helpers

    public static class LanguageHelpers {
        public static SysLangs FromISO639_1( this string code ) {
            if( string.IsNullOrWhiteSpace( code ) ) {
                throw new ArgumentNullException( code );
            }
            switch( code.ToUpper() ) {
#if !Brand_UperTaxi
            default:
#endif
            case "RUS":
                return SysLangs.RU;
            case "UKR":
                return SysLangs.UK;
#if Brand_UperTaxi
            default:
#endif
            case "ENG":
                return SysLangs.EN;
            case "LIT":
                return SysLangs.LT;
            case "AZE":
                return SysLangs.AZ;
            }
        }

        public static string ToCulture( this SysLangs lang ) {
            switch( lang ) {
            default:
            case SysLangs.RU:
                return "ru-RU";
            case SysLangs.UK:
                return "uk-UA";
            case SysLangs.EN:
                return "en-US";
            case SysLangs.LT:
                return "lt-LT";
            case SysLangs.AZ:
                return "az-AZ";
            }
        }
    }

    #endregion
}
