﻿using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;

namespace YTxCommon.App.Enums {
    /// <summary>
    ///     Типы платёжных систем
    /// </summary>
    public enum PaymentSystems {
        WayForPay = 0,
        EposAz = 1
    }

    /// <summary>
    ///     Типы счетов, используемых в платёжной системе
    /// </summary>
    public enum PaymentAccountTypes {
        /// <summary>
        ///     Банковская карточка
        /// </summary>
        BankCard = 0,

        /// <summary>
        ///     Номер телефона
        /// </summary>
        Phone = 1
    }

    /// <summary>
    ///     Ошибки платёжных систем
    /// </summary>
    public enum PaymentSystemResultCodes {
        /// <summary>
        ///     Операция выполнена успешно
        /// </summary>
        Success = 0,

        /// <summary>
        ///     Платёжная система не ответила своевременно
        /// </summary>
        Timeout = 1,

        /// <summary>
        ///     Ошибка формата ответа платёжной системы
        /// </summary>
        BadAnswer = 2,

        /// <summary>
        ///     Ошибка платёжной системы
        /// </summary>
        PaymentSystemError = 3,

        /// <summary>
        ///     Внутренняя ошибка
        /// </summary>
        InternalError = 4,

        /// <summary>
        ///     Неверные значения параметров
        /// </summary>
        InvalidParameters = 5,

        /// <summary>
        ///     Недостаточно средств на счёте
        /// </summary>
        InsufficientMeans = 6,

        /// <summary>
        ///     Счёт не может быть использован (карта просрочена, карта в недопустимом состоянии, неверное значение token и т.п.)
        /// </summary>
        AccountCannotBeUsed = 7,

        /// <summary>
        ///     Счёт временно недоступен (превышен лимит операций по карте и т.п.)
        /// </summary>
        AccountTemporarilyUnavailable = 8,

        /// <summary>
        ///     Отсутствует доступная платёжная система
        /// </summary>
        AccessibleEngineAbsent = 9
    }

    /// <summary>
    ///     Параметры платёжных систем
    /// </summary>
    public static class PaymentSystemsParameters {
        public static readonly ReadOnlyDictionary<PaymentSystems, List<PaymentAccountTypes>> AccountTypes =
            new ReadOnlyDictionary<PaymentSystems, List<PaymentAccountTypes>>(
                new Dictionary<PaymentSystems, List<PaymentAccountTypes>> {
                    {
                        PaymentSystems.WayForPay,
                        new List<PaymentAccountTypes> {PaymentAccountTypes.BankCard}
                    }, {
                        PaymentSystems.EposAz,
                        new List<PaymentAccountTypes> {PaymentAccountTypes.BankCard}
                    }
                } );

        public static List<PaymentAccountTypes> AccountTypesSupported( PaymentSystems? paymentSystem ) {
            if( paymentSystem == null ) {
                return null;
            }
            AccountTypes.TryGetValue( paymentSystem.Value, out var accountTypes );
            return accountTypes;
        }

        public static bool AccountTypeSupported( PaymentSystems? paymentSystem, PaymentAccountTypes accountType ) {
            if( paymentSystem == null ) {
                return false;
            }
            if( !AccountTypes.TryGetValue( paymentSystem.Value, out var accountTypes ) ) {
                return false;
            }
            return accountTypes != null && accountTypes.Any( x => x == accountType );
        }
    }
}
