﻿namespace ServerAppAPI.API {
    /// <summary>
    ///     Команды API
    /// </summary>
    public enum Commands {
        /// <summary>
        ///     Версия системы
        /// </summary>
        Version,

        /// <summary>
        ///     Получение информации по поставщику услуг
        /// </summary>
        ProviderInfoQuery,

        /// <summary>
        ///     Запрос реестров
        /// </summary>
        RegistersQuery,

        /// <summary>
        ///     Запрос геоданных
        /// </summary>
        GeoDataQuery,

        /// <summary>
        ///     Запрос адреса по координатам
        /// </summary>
        AddressByGPSQuery,

        /// <summary>
        ///     Запрос координат по адресу
        /// </summary>
        PointsByGPSQuery,

        /// <summary>
        ///     Добавление нового заказа
        /// </summary>
        AddNewOrder,

        /// <summary>
        ///     Получение информации по заказу
        /// </summary>
        OrderInfoQuery,

        /// <summary>
        ///     Получение информации по клиенту
        /// </summary>
        ClientInfoQuery,

        /// <summary>
        ///     Получение фото клиента
        /// </summary>
        ClientPhotoQuery,

        /// <summary>
        ///     Получение информации по карточке лояльности
        /// </summary>
        LoyalCardInfoQuery,

        /// <summary>
        ///     Получение информации по безналичной карточке
        /// </summary>
        NonCashCardInfoQuery,

        /// <summary>
        ///     Добавление/обновление информации по клиенту
        /// </summary>
        ClientInfoSet,

        /// <summary>
        ///     Добавление/обновление фото клиента
        /// </summary>
        ClientPhotoSet,

        /// <summary>
        ///     Установка параметров Push-уведомлений клиента
        /// </summary>
        ClientPushParamsSet,

        /// <summary>
        ///     Добавление/обновление информации по карточке лояльности
        /// </summary>
        LoyalCardInfoSet,

        /// <summary>
        ///     Добавление/обновление информации по безналичной карточке
        /// </summary>
        NonCashCardInfoSet,

        /// <summary>
        ///     Пополнение карточки лояльности
        /// </summary>
        LoyalCardReplenishment,

        /// <summary>
        ///     Получение статуса заказа
        /// </summary>
        OrderStatusQuery,

        /// <summary>
        ///     Назначение статуса заказа
        /// </summary>
        OrderStatusSet,

        /// <summary>
        ///     Получение примечания заказа
        /// </summary>
        OrderNoteQuery,

        /// <summary>
        ///     Назначение примечания заказа
        /// </summary>
        OrderNoteSet,

        /// <summary>
        ///     Отказ клиента
        /// </summary>
        OrderClientRejection,

        /// <summary>
        ///     Получение перечня водителей, предложенных для выполнения заказа
        /// </summary>
        OrderEstimatedDriversQuery,

        /// <summary>
        ///     Выбор водителя
        /// </summary>
        OrderDriverSelection,

        /// <summary>
        ///     Перезапуск процесса обработки заказа (поиска водителей)
        /// </summary>
        OrderRestartProcess,

        /// <summary>
        ///     Перевод заказа в режим автоматического поиска водителей
        /// </summary>
        OrderAutoSearchDrivers,

        /// <summary>
        ///     Подтверждение оплаты заказа
        /// </summary>
        OrderPaymentConfirmation,

        /// <summary>
        ///     Получение фото водителя
        /// </summary>
        OrderDriverPhotoQuery,

        /// <summary>
        ///     Получение фото автомобиля
        /// </summary>
        OrderCarPhotoQuery,

        /// <summary>
        ///     Расчёт заказа (без создания записи заказа)
        /// </summary>
        OrderCalculateOnly,

        /// <summary>
        ///     Получение перечня заказов по клиенту
        /// </summary>
        OrderListQuery,

        /// <summary>
        ///     Получение рейтинга водителя по заказу
        /// </summary>
        OrderDriverRatingQuery,

        /// <summary>
        ///     Назначение рейтинга водителя по заказу
        /// </summary>
        OrderDriverRatingSet,

        /// <summary>
        ///     Получение перечня доступных водителей
        /// </summary>
        AvailableDriversQuery,

        /// <summary>
        ///     Регистрация счёта клиента
        /// </summary>
        ClientAccountRegistration,

        /// <summary>
        ///     Изменение реквизитов счёта клиента
        /// </summary>
        ClientAccountModification,

        /// <summary>
        ///     Оплата со счёта клиента
        /// </summary>
        ClientAccountPayment,

        /// <summary>
        ///     Получение реестра операций по счёту
        /// </summary>
        ClientAccountOperationsQuery,

        /// <summary>
        ///     Получение информации по отношениям между потребителями услуг
        /// </summary>
        ConsumersRelationsInfoQuery,

        /// <summary>
        ///     Добавление/обновление информации по отношениям между потребителями услуг
        /// </summary>
        ConsumersRelationsInfoSet,

        /// <summary>
        ///     Получение информации по отношениям между клиентом и водителями
        /// </summary>
        DriversRelationsInfoQuery,

        /// <summary>
        ///     Добавление/обновление информации по отношениям между клиентом и водителем
        /// </summary>
        DriversRelationsInfoSet,

        /// <summary>
        ///     Получение информации по карточкам лояльности
        /// </summary>
        LoyalCardsInfoQuery,

        /// <summary>
        ///     Межсистемный обмен. Получение информации по водителю
        /// </summary>
        XchgDriverInfoQuery,

        /// <summary>
        ///     Межсистемный обмен. Добавление/обновление информации по водителю
        /// </summary>
        XchgDriverInfoSet,

        /// <summary>
        ///     Межсистемный обмен. Получение фото автомобиля водителя
        /// </summary>
        XchgDriverCarPhotoQuery,

        /// <summary>
        ///     Межсистемный обмен. Добавление/обновление фото автомобиля водителя
        /// </summary>
        XchgDriverCarPhotoSet,

        /// <summary>
        ///     Добавление карточки лояльности
        /// </summary>
        LoyalCardCreate
    }

    /// <summary>
    ///     Виды реестров
    /// </summary>
    public enum RegisterTypes {
        Towns,
        Streets,
        ObjectPlaces,
        Providers,
        CarClasses,
        OrderTypes,
        OrderStatuses,
        OrderSubStatuses,
        ClientStatuses,
        DriverShiftStatuses,
        PayTypes,
        Tariffs,
        CarColors,
        CarMakers,
        CarModels
    }

    /// <summary>
    ///     Виды запросов геоданных
    /// </summary>
    public enum GeoDataRequestTypes {
        Houses,
        Places,
        Streets
    }

    /// <summary>
    ///     Коды результата выполнения команды
    /// </summary>
    public enum ResultCodes {
        /// <summary>
        ///     Успешно
        /// </summary>
        Success,

        /// <summary>
        ///     Ошибка сервера
        /// </summary>
        ServerError,

        /// <summary>
        ///     Ошибка аутентификации
        /// </summary>
        AuthenticationError,

        /// <summary>
        ///     Некорректные параметры
        /// </summary>
        InvalidParameters
    }

    #region Helpers

    public static class APICommandsHelper {
        public static bool CommandRequiresRegistration( this Commands command ) {
            switch( command ) {
            case Commands.Version:
            case Commands.ProviderInfoQuery:
            case Commands.RegistersQuery:
            case Commands.AddressByGPSQuery:
            case Commands.PointsByGPSQuery:
            case Commands.OrderCalculateOnly:
            case Commands.AvailableDriversQuery:
                return false;
            default:
                return true;
            }
        }

        public static bool CommandXchg( this Commands command ) {
            switch( command ) {
            case Commands.XchgDriverInfoQuery:
            case Commands.XchgDriverInfoSet:
            case Commands.XchgDriverCarPhotoQuery:
            case Commands.XchgDriverCarPhotoSet:
                return true;
            default:
                return false;
            }
        }
    }

    #endregion
}
